# YtmUrl

## Installation

```
pip install ytmurl
```

## Usage

```
usage: ytmurl [-h] [--log-file LOG] [-d DURATION] query

searches youtube music and prints audio url

positional arguments:
  query                 query string containing title, artist, etc

optional arguments:
  -h, --help            show this help message and exit
  --log-file LOG        log file to append to
  -d DURATION, --duration DURATION
                        duration of song in miliseconds
```
